==> google-cloud-sdk-463.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/apphub/service_projects/describe.py <==
# -*- coding: utf-8 -*- #
# Copyright 2023 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command to describe a Service Project."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.apphub import service_projects as apis
from googlecloudsdk.calliope import base
from googlecloudsdk.calliope import exceptions
from googlecloudsdk.command_lib.apphub import flags

_DETAILED_HELP = {
    'DESCRIPTION': '{description}',
    'EXAMPLES': """ \
        To describe the service project `my-service-project` attached to the
        host project `my-host-project`, run:

          $ {command} my-service-project --project=my-host-project
        """,
}


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class Describe(base.DescribeCommand):
  """Describe an Apphub service project."""

  detailed_help = _DETAILED_HELP

  @staticmethod
  def Args(parser):
    flags.AddDescribeServiceProjectFlags(parser)

  def Run(self, args):
    """Run the describe command."""
    client = apis.ServiceProjectsClient()
    service_project_ref = args.CONCEPTS.service_project.Parse()
    if not service_project_ref.Name():
      raise exceptions.InvalidArgumentException(
          'service project', 'service project id must be non-empty.'
      )
    return client.Describe(service_project=service_project_ref.RelativeName())

==> google-cloud-sdk-466.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/surface/apphub/service_projects/describe.py <==
# -*- coding: utf-8 -*- #
# Copyright 2023 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Command to describe a Service Project."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.apphub import service_projects as apis
from googlecloudsdk.calliope import base
from googlecloudsdk.calliope import exceptions
from googlecloudsdk.command_lib.apphub import flags

_DETAILED_HELP = {
    'DESCRIPTION': '{description}',
    'EXAMPLES': """ \
        To describe the service project `my-service-project` attached to the
        host project `my-host-project`, run:

          $ {command} my-service-project --project=my-host-project
        """,
}


@base.Hidden
@base.ReleaseTracks(base.ReleaseTrack.GA)
class DescribeGA(base.DescribeCommand):
  """Describe an Apphub service project."""

  detailed_help = _DETAILED_HELP

  @staticmethod
  def Args(parser):
    flags.AddDescribeServiceProjectFlags(parser)

  def Run(self, args):
    """Run the describe command."""
    client = apis.ServiceProjectsClient(release_track=base.ReleaseTrack.GA)
    service_project_ref = args.CONCEPTS.service_project.Parse()
    if not service_project_ref.Name():
      raise exceptions.InvalidArgumentException(
          'service project', 'service project id must be non-empty.'
      )
    return client.Describe(service_project=service_project_ref.RelativeName())


@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
class DescribeAlpha(base.DescribeCommand):
  """Describe an Apphub service project."""

  detailed_help = _DETAILED_HELP

  @staticmethod
  def Args(parser):
    flags.AddDescribeServiceProjectFlags(parser)

  def Run(self, args):
    """Run the describe command."""
    client = apis.ServiceProjectsClient(release_track=base.ReleaseTrack.ALPHA)
    service_project_ref = args.CONCEPTS.service_project.Parse()
    if not service_project_ref.Name():
      raise exceptions.InvalidArgumentException(
          'service project', 'service project id must be non-empty.'
      )
    return client.Describe(service_project=service_project_ref.RelativeName())
